@@ -526,10 +526,10 @@ class Zone(ZoneSchedule, ZoneBase):
             Command.get_zone_name(self.ctl.id, self.idx), 60 * 60 * 6, delay=30
         )
 
-        self._add_discovery_task(
+        self._add_discovery_task(  # 2349 instead of 2309
             Command.get_zone_mode(self.ctl.id, self.idx), 60 * 5, delay=30
         )
-        self._add_discovery_task(
+        self._add_discovery_task(  # 30C9
             Command.get_zone_temp(self.ctl.id, self.idx), 60 * 5, delay=0
         )  # td should be > sync_cycle duration,?delay in hope of picking up cycle
         self._add_discovery_task(
@@ -892,7 +892,7 @@ def _transform(valve_pos: float) -> float:
 ZONE_CLASS_BY_SLUG = class_by_attr(__name__, "_SLUG")  # ZON_ROLE.RAD: RadZone
 
 
-def zx_zone_factory(tcs, idx: str, *, msg: Message = None, **schema) -> _ZoneT:
+def zone_factory(tcs, idx: str, *, msg: Message = None, **schema) -> _ZoneT:
     """Return the zone class for a given zone_idx/klass (Zone or DhwZone).
 
     Some zones are promotable to a compatible sub class (e.g. ELE->VAL).
